package net.bigeon.gclc.system;

/*-
 * #%L
 * GCLC system command
 * %%
 * Copyright (C) 2016 - 2018 Bigeon
 * %%
 * This software is governed by the CeCILL  license under French law and
 * abiding by the rules of distribution of free software.  You can  use,
 * modify and/ or redistribute the software under the terms of the CeCILL
 * license as circulated by CEA, CNRS and INRIA at the following URL
 * "http://www.cecill.info".
 * 
 * As a counterpart to the access to the source code and  rights to copy,
 * modify and redistribute granted by the license, users are provided only
 * with a limited warranty  and the software's author,  the holder of the
 * economic rights,  and the successive licensors  have only  limited
 * liability.
 * 
 * In this respect, the user's attention is drawn to the risks associated
 * with loading,  using,  modifying and/or developing or reproducing the
 * software by the user in light of its specific status of free software,
 * that may mean  that it is complicated to manipulate,  and  that  also
 * therefore means  that it is reserved for developers  and  experienced
 * professionals having in-depth computer knowledge. Users are therefore
 * encouraged to load and test the software's suitability as regards their
 * requirements in conditions enabling the security of their systems and/or
 * data to be ensured and,  more generally, to use and operate it in the
 * same conditions as regards security.
 * 
 * The fact that you are presently reading this means that you have had
 * knowledge of the CeCILL license and that you accept its terms.
 * #L%
 */
import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertNotNull;
import static org.junit.Assert.fail;

import org.junit.Test;

import net.bigeon.gclc.exception.CommandRunException;
import net.bigeon.gclc.manager.ConsoleInput;
import net.bigeon.gclc.manager.ConsoleOutput;
import net.bigeon.gclc.utils.EmptyInput;
import net.bigeon.gclc.utils.SinkOutput;

public class ExecSystemCommandTest {

    /** Test the help methods of the command. */
    @Test
    public void testExecSystemCommand() {
        final ExecSystemCommand cmd = new ExecSystemCommand("test");
        assertEquals("Name should be preserved", "test", cmd.getCommandName());
        assertNotNull("tip should be defined", cmd.tip());
        assertNotNull("usage should be defined", cmd.usagePattern());
        assertNotNull("usage should be defined", cmd.usageDetail());
    }

    /** Test the execution of the command.
     * 
     * @throws CommandRunException */
    @Test
    public void testExecute() throws CommandRunException {
        final ConsoleOutput out = SinkOutput.INSTANCE;
        final ConsoleInput in = EmptyInput.INSTANCE;

        final ExecSystemCommand cmd = new ExecSystemCommand();
        if (System.getProperty("os.name").contains("indows")) {
            cmd.execute(out, in, "cmd", "/C", "dir");
        } else if (System.getProperty("os.name").contains("inux")) {
            cmd.execute(out, in, "ls");
        }
        try {
            cmd.execute(out, in, "inexistent");
            fail("Able to execute inexistent command in system");
        } catch (final CommandRunException e) {
            // ok
        }
    }

}
